==> readfile-go-1.0.1.tgz: package/js/normaliseOptions/index.js <==
'use strict'

function isObject(obj) {
  return obj !== null && typeof obj === 'object' && !Array.isArray(obj)
}

function toBoolean(bool) {
  if (bool === 'false') bool = false
  return !!bool
}

function normaliseOptions(options) {

  var DEFAULTS = require('./defaultOptions')

  if (options == null || !isObject(options)) {
    options = {}
  } else {

    // null is allowed here (for buffer)
    if (options.encoding != null && typeof options.encoding !== 'string') {
      options.encoding = DEFAULTS.encoding
    }

    if (typeof options.flag !== 'undefined' && typeof options.flag !== 'string') {
      options.flag = DEFAULTS.flag
    }

    if (typeof options.logFunc !== 'undefined' && typeof options.logFunc !== 'function') {
      options.logFunc = DEFAULTS.logFunc
    }

    // null is allowed here (default)
    if (options.message != null && typeof options.message !== 'string') {
      options.message = DEFAULTS.message
    }

    if (typeof options.save !== 'undefined') {
      options.save = toBoolean(options.save)
    }

    if (typeof options.saveMessage !== 'undefined') {
      options.saveMessage = toBoolean(options.saveMessage)
    }

    if (typeof options.silent !== 'undefined') {
      options.silent = toBoolean(options.silent)
    }

    if (typeof options.throw !== 'undefined') {
      options.throw = toBoolean(options.throw)
    }
  }

  options = Object.assign({}, DEFAULTS, options)

  if (options.encoding != null) {
    options.encoding = options.encoding.trim()
  }

  options.flag = options.flag.trim()

  // logFunc
  // nothing to do

  // message
  if (options.message != null) {
    options.message = options.message.trim()
  }

  // silent
  // nothing to do

  // throw
  // nothing to do

  // save
  if (options.save) {
    DEFAULTS.encoding = options.encoding
    DEFAULTS.flag = options.flag
    DEFAULTS.logFunc = options.logFunc
    DEFAULTS.silent = options.silent
    DEFAULTS.throw = options.throw
  }

  // saveMessage
  if (options.saveMessage) {
    DEFAULTS.message = options.message
  }

  return options
}

module.exports = normaliseOptions

==> readfile-go-1.0.3.tgz: package/js/normaliseOptions/index.js <==
'use strict'

function isObject(obj) {
  return obj !== null && typeof obj === 'object' && !Array.isArray(obj)
}

function toBoolean(bool) {
  if (bool === 'false') bool = false
  return !!bool
}

function normaliseOptions(options) {

  var DEFAULTS = require('./defaultOptions')

  if (!isObject(options)) {
    options = {}
  } else {

    // null is allowed here (for buffer)
    if (options.encoding != null && typeof options.encoding !== 'string') {
      options.encoding = DEFAULTS.encoding
    }

    if (typeof options.flag !== 'undefined' && typeof options.flag !== 'string') {
      options.flag = DEFAULTS.flag
    }

    if (typeof options.logFunc !== 'undefined' && typeof options.logFunc !== 'function') {
      options.logFunc = DEFAULTS.logFunc
    }

    // null is allowed here (default)
    if (options.message != null && typeof options.message !== 'string') {
      options.message = DEFAULTS.message
    }

    if (typeof options.save !== 'undefined') {
      options.save = toBoolean(options.save)
    }

    if (typeof options.saveMessage !== 'undefined') {
      options.saveMessage = toBoolean(options.saveMessage)
    }

    if (typeof options.silent !== 'undefined') {
      options.silent = toBoolean(options.silent)
    }

    if (typeof options.throw !== 'undefined') {
      options.throw = toBoolean(options.throw)
    }
  }

  options = Object.assign({}, DEFAULTS, options)

  if (options.encoding != null) {
    options.encoding = options.encoding.trim()
  }

  options.flag = options.flag.trim()

  // logFunc
  // nothing to do

  // message
  if (options.message != null) {
    options.message = options.message.trim()
  }

  // silent
  // nothing to do

  // throw
  // nothing to do

  // save
  if (options.save) {
    DEFAULTS.encoding = options.encoding
    DEFAULTS.flag = options.flag
    DEFAULTS.logFunc = options.logFunc
    DEFAULTS.silent = options.silent
    DEFAULTS.throw = options.throw
  }

  // saveMessage
  if (options.saveMessage) {
    DEFAULTS.message = options.message
  }

  return options
}

module.exports = normaliseOptions
